#include <stdio.h>
#include <cstdlib>
#include <stdlib.h>
#include <SDL/SDL.h>
#include "fonction.c"
#include <windows.h>
#include <string.h>


// CONSTANTES
//-------------------------------------------------------------------------------
// Dfinition du code d'erreurs
typedef enum
{
    e_ErrCom_None, // Pas d'erreur
    e_ErrCom_Creation, // Erreur lors de la cration du flux e_ErrCom_Utilise, // Le port com est dj utilis
    e_ErrCom_Inexistant, // Le port com n'existe pas
    e_ErrCom_Timeout, // Timeout lors d'une mission-rception
    e_ErrCom_Emission, // Erreur lors de l'mission
    e_ErrCom_Reception, // Erreur lors de la rception
    e_ErrCom_Definition_Trame, // Erreur de dfinition de la trame
    e_ErrCom_Nack, // Demande non prise en coompte
    e_ErrCom_Checksum // Erreur de checksum
} e_ErrCom;

// Nom du port srie
#define PORT1 "COM1"
#define PORT2 "COM2"

// Dfinition des vitesses de communication
#define V1200 1200
#define V2400 2400
#define V4800 4800
#define V9600 9600

// Dfinition du nombre de bits
#define BITS_7 7
#define BITS_8 8

// Dfinition du nombre de bits de stop
#define BIT_DE_STOP_1 1
#define BIT_DE_STOP_2 2

// Dfinition de la parit
#define PAS_DE_PARITE 'N'
#define PARITE_IMPAIRE 'O'
#define PARITE_PAIRE 'E'

// Codes de retour gnriques
#define OK 1
#define KO 0

// Longueur max rserve pour une trame
#define LG_TRAME 100

// PROTOTYPES
//----------------------------------------------------------------------------
e_ErrCom OuvreCom(char *strPort,long BaudRate,int BitsSize,int Parity,int StopBits);
e_ErrCom EmissionCom(const void *lpBuf, unsigned int nCount);
e_ErrCom ReceptionCom(void *lpBuf, unsigned int nCountMax, unsigned int *pCountRead);
void FermeCom();

// VARIABLES GLOBALES
//-----------------------------------------------------------------------------
DCB g_DCB; // structure dcb du port
e_ErrCom g_ErrCom= e_ErrCom_None; // Variable des erreurs de com
HANDLE g_hCom = 0; // handle de la com

int main (int argc,char *argv[])
{

    int nId=1, nChoice, nBytesWritten, nBytesRead;
    SDL_Init(SDL_INIT_VIDEO);
    input in;
    SDL_Surface *ecran=NULL,*menu=NULL;
    ecran=SDL_SetVideoMode(500,600,32,SDL_HWSURFACE);
    menu=SDL_LoadBMP("menu.bmp");
    SDL_Rect position;
    position.x=0;
    position.y=0;
    memset(&in,0,sizeof(in));
    char buffer1=NULL;
    char buffer2=NULL;
    char *pointer=NULL;
    while (!in.key[SDLK_ESCAPE]&&!in.quit)
    {
        traitementInfo(&in);
buffer1='B';
buffer2='N';

        if (in.key[SDLK_1]==1)
        {


            in.key[SDLK_1]=0;/*quand j'apui 1 le portCom envoie la lettre B en binaire et on sort du menu pour que l'image de la diode clair apparais*/
            g_ErrCom=OuvreCom(PORT1,V9600,BITS_8,PAS_DE_PARITE,BIT_DE_STOP_1);
            g_ErrCom=EmissionCom(&buffer1,sizeof(buffer1));
           pointer=&buffer1;


            FermeCom();
            ledAllume(ecran);/*on sort du menu image de la diode Allum*/

        }

        if (in.key[SDLK_2]==1)
        {
            in.key[SDLK_2]=0;
            g_ErrCom=OuvreCom(PORT1,V9600,BITS_8,PAS_DE_PARITE,BIT_DE_STOP_1);/*quand j'apui 0 le portCom envoie la lettre A en binaire et on sort du menu pour que l'image de la diode teint  apparais*/
            g_ErrCom=EmissionCom(&buffer2,sizeof(buffer2));
            FermeCom();
          pointer=&buffer2;

            ledEteint(ecran);/*on sort du menu image de la diode teint*/

        }
        SDL_FillRect(ecran,NULL,SDL_MapRGB((*ecran).format,255,255,255));
        SDL_BlitSurface(menu,NULL,ecran,&position);/*dans le menu */
        SDL_Flip(ecran);
    }
    SDL_FreeSurface(menu);


}

e_ErrCom OuvreCom(char *strPort,long BaudRate,int BitsSize,int Parity,int StopBits)
{
    g_ErrCom = e_ErrCom_None;

// On ouvre le port srie
    g_hCom = CreateFile(strPort,GENERIC_READ | GENERIC_WRITE,0,NULL,OPEN_EXISTING,FILE_FLAG_WRITE_THROUGH | FILE_FLAG_NO_BUFFERING,NULL);

    if (g_hCom == INVALID_HANDLE_VALUE)
    {
// Echec
        g_ErrCom=e_ErrCom_Creation;
    }
    else
    {
// On vide les buffers
        PurgeComm(g_hCom,PURGE_TXABORT|PURGE_RXABORT|PURGE_TXCLEAR|PURGE_RXCLEAR);

// On paramtre le port srie
        g_DCB.DCBlength = sizeof(DCB);
//Configuration actuelle
        GetCommState(g_hCom, &g_DCB);
//Modification du DCB
        g_DCB.BaudRate=CBR_9600;
        g_DCB.ByteSize=8;
        g_DCB.Parity=NOPARITY;
        g_DCB.StopBits=ONESTOPBIT;
        g_DCB.fDtrControl=DTR_CONTROL_DISABLE;

//Configuration de la liaison serie
        SetCommState(g_hCom,&g_DCB);


    }
    return g_ErrCom;
}



//----------------------------------------------------------------------------
// FONCTION : EmissionCom
//----------------------------------------------------------------------------
// DESCRIPTION :
// Emission d'octets sur la liaison srie
//
//----------------------------------------------------------------------------
// PARAMETRES :
// -lpBuf Pointeur sur les octets a emettre
// -nCount Nombre d'octet a emettre
//
//----------------------------------------------------------------------------
// RETOUR :Code d'erreur#
//----------------------------------------------------------------------------
e_ErrCom EmissionCom(const void* lpBuf,unsigned int nCount)
{

    DWORD NumBytes=0;

    if (g_hCom!=NULL)
    {
// On pari sur pas d'erreur
        g_ErrCom=e_ErrCom_None;

//Emission du buffer#
        if (WriteFile(g_hCom,lpBuf,nCount,&NumBytes,NULL)==0)
        {
            g_ErrCom=e_ErrCom_Emission;
        }
    }
    else
//Le port n'a pas t ouvert
        g_ErrCom=e_ErrCom_Creation;


    return g_ErrCom;

}

//---------------------------------------------------------------------------
// FONCTION : ReceptionCom
//---------------------------------------------------------------------------
// DESCRIPTION :
// Reception de caractres sur la liaison srie
//
//---------------------------------------------------------------------------
// PARAMETRES :
// -lpBuf Pointeur sur le buffer de caractre a lire
// -nCountMax Nombre maxi de caractre a lire
// -pCountRead Pointeur sur le nombre de caractres lus
//---------------------------------------------------------------------------
// RETOUR :Code d'erreur
//---------------------------------------------------------------------------
e_ErrCom ReceptionCom(void *lpBuf,unsigned int nCountMax, unsigned int* pCountRead)
{
    COMSTAT Stat;
    DWORD Errors;
    unsigned int nCarALire;
    unsigned long NCarLus=0;

    if (g_hCom!=NULL)
    {
//on pari sur pas d'erreur
        g_ErrCom=e_ErrCom_None;

//Pour viter de grer un time out
        Sleep(500);

//Pour connaitre le nombre d'octets dans le buffer d'entre
        ClearCommError(g_hCom,&Errors,&Stat);
        nCarALire=Stat.cbInQue;

//On effectue la lecture si il y a des caractres prsents
        if ( (nCarALire>0)&&(nCarALire<=nCountMax) )
        {
            if (ReadFile(g_hCom,lpBuf,nCarALire,&NCarLus,NULL)==0)
            {
                g_ErrCom=e_ErrCom_Reception;
            }

        }
        *pCountRead=NCarLus;
    }
    else

        //Le port n a pas t ouvert
        g_ErrCom=e_ErrCom_Creation;
//Compte rendu de l'excution
    return g_ErrCom;
}
void FermeCom()
{
    if (g_hCom!=NULL)
    {
        CloseHandle(g_hCom);
    }
}

